import { CAIntermediateFileLocations } from './caFileLocations.js';
import { deviceFileLocations } from './deviceFileLocations.js';
import { initDb, openssl } from './openssl.js';
import { opensslConfig } from './opensslConfig.js';
export const createSimulatorKeyAndCSR = async ({ certsDir, log, debug, deviceId, intermediateCertId, }) => {
    log === null || log === void 0 ? void 0 : log(`Generating key and CSR for device ${deviceId}`);
    const caIntermediateFiles = CAIntermediateFileLocations({
        certsDir,
        id: intermediateCertId,
    });
    const { privateKey, csr } = deviceFileLocations({
        certsDir,
        deviceId,
    });
    const opensslV3 = openssl({ debug });
    await initDb({ debug, certsDir });
    await opensslV3.command('ecparam', '-out', privateKey, '-name', 'prime256v1', '-genkey');
    await opensslV3.command('req', '-config', opensslConfig({
        dir: certsDir,
        certificateFile: caIntermediateFiles.cert,
        privateKeyFile: caIntermediateFiles.privateKey,
    }), '-key', privateKey, '-subj', `/CN=${deviceId}`, '-new', '-sha256', '-out', csr);
};
