import { CAIntermediateFileLocations, CARootFileLocations, } from './caFileLocations.js';
import { certificateName } from './certificateName.js';
import { initDb, openssl } from './openssl.js';
import { opensslConfig } from './opensslConfig.js';
export const defaultIntermediateCAValidityInDays = 365;
export const generateCAIntermediate = async ({ certsDir, log, id, debug, daysValid, }) => {
    const { privateKey, cert, csr } = CAIntermediateFileLocations({
        certsDir,
        id,
    });
    const intermediateName = certificateName(`nrfassettracker-intermediate-${id}`);
    const opensslV3 = openssl({ debug });
    await initDb({ debug, certsDir });
    await opensslV3.command('genrsa', '-aes256', '-passout', 'pass:1234', '-out', privateKey, '4096');
    await opensslV3.command('req', '-new', '-sha256', '-passin', 'pass:1234', '-config', opensslConfig({
        dir: certsDir,
        certificateFile: cert,
        privateKeyFile: privateKey,
    }), '-subj', `/CN=${intermediateName}`, '-key', privateKey, '-out', csr);
    const caRootFiles = CARootFileLocations(certsDir);
    await opensslV3.command('ca', '-batch', '-config', opensslConfig({
        dir: certsDir,
        certificateFile: caRootFiles.cert,
        privateKeyFile: caRootFiles.privateKey,
    }), '-passin', 'pass:1234', '-extensions', 'v3_intermediate_ca', '-days', `${daysValid !== null && daysValid !== void 0 ? daysValid : 30}`, '-notext', '-md', 'sha256', '-in', csr, '-out', cert);
    debug === null || debug === void 0 ? void 0 : debug(await opensslV3.command('x509', '-noout', '-text', '-in', cert));
    log('Intermediate CA Certificate', cert);
    return { name: intermediateName };
};
