import { promises as fs } from 'fs';
import { CARootFileLocations } from './caFileLocations.js';
import { openssl } from './openssl.js';
import { opensslConfig } from './opensslConfig.js';
export const defaultCAValidityInDays = 365;
export const generateCARoot = async ({ certsDir, name, log, debug, daysValid, }) => {
    const { cert, privateKey } = CARootFileLocations(certsDir);
    try {
        await fs.stat(certsDir);
    }
    catch {
        await fs.mkdir(certsDir, { recursive: true });
        debug === null || debug === void 0 ? void 0 : debug(`Created ${certsDir}`);
    }
    let certExists = false;
    try {
        await fs.stat(cert);
        certExists = true;
    }
    catch {
    }
    if (certExists) {
        throw new Error(`CA Root certificate exists: ${cert}!`);
    }
    const opensslV3 = openssl({ debug });
    await opensslV3.command('genrsa', '-aes256', '-passout', 'pass:1234', '-out', privateKey, '4096');
    await opensslV3.command('req', '-new', '-x509', '-config', opensslConfig({
        dir: certsDir,
        certificateFile: cert,
        privateKeyFile: privateKey,
    }), '-passin', 'pass:1234', '-key', privateKey, '-subj', `/CN=${name}`, '-days', `${daysValid !== null && daysValid !== void 0 ? daysValid : 90}`, '-sha256', '-extensions', 'v3_ca', '-out', cert);
    debug === null || debug === void 0 ? void 0 : debug(await opensslV3.command('x509', '-noout', '-text', '-in', cert));
    log('Root CA Certificate', cert);
};
