import { writeFile } from 'fs/promises';
import { CAIntermediateFileLocations } from './caFileLocations.js';
import { deviceFileLocations } from './deviceFileLocations.js';
import { fingerprint } from './fingerprint.js';
import { openssl } from './openssl.js';
import { opensslConfig } from './opensslConfig.js';
export const defaultDeviceCertificateValidityInDays = 10950;
export const generateDeviceCertificate = async ({ certsDir, log, debug, deviceId, intermediateCertId, daysValid, }) => {
    log === null || log === void 0 ? void 0 : log(`Generating certificate for device ${deviceId}`);
    const caIntermediateFiles = CAIntermediateFileLocations({
        certsDir,
        id: intermediateCertId,
    });
    const { cert, csr, intermediateCertId: intermediateCertIdFile, } = deviceFileLocations({
        certsDir,
        deviceId,
    });
    debug === null || debug === void 0 ? void 0 : debug(`Intermediate certificate fingerprint`, await fingerprint(caIntermediateFiles.cert));
    const opensslV3 = openssl({ debug });
    await opensslV3.command('ca', '-batch', '-config', opensslConfig({
        dir: certsDir,
        certificateFile: caIntermediateFiles.cert,
        privateKeyFile: caIntermediateFiles.privateKey,
    }), '-passin', 'pass:1234', '-extensions', 'usr_cert', '-days', `${daysValid !== null && daysValid !== void 0 ? daysValid : 30}`, '-notext', '-md', 'sha256', '-in', csr, '-out', cert);
    debug === null || debug === void 0 ? void 0 : debug(await opensslV3.command('x509', '-noout', '-text', '-in', cert));
    await writeFile(intermediateCertIdFile, intermediateCertId, 'utf-8');
    debug === null || debug === void 0 ? void 0 : debug(`${intermediateCertIdFile} written`);
};
