import chalk from 'chalk';
import { stat, writeFile } from 'fs/promises';
import { execFile } from 'node:child_process';
import * as path from 'path';
const command = async ({ cmd, args, debug, }) => new Promise((resolve, reject) => {
    debug === null || debug === void 0 ? void 0 : debug(`[${cmd}] »`, ...args.map((s) => chalk.gray(s)));
    execFile('openssl', args, {
        timeout: 60 * 1000,
    }, (err, stdout, stderr) => {
        if (err !== null) {
            debug === null || debug === void 0 ? void 0 : debug(`[${cmd}] «`, stderr);
            return reject(err);
        }
        if (stdout.length > 0)
            debug === null || debug === void 0 ? void 0 : debug(`[${cmd}] «`, stdout);
        return resolve(stdout);
    });
});
export const openssl = ({ debug, expectedVersion, }) => ({
    command: async (...args) => {
        const version = await command({ cmd: 'openssl', args: ['version'] });
        if (!version.includes(`OpenSSL ${expectedVersion !== null && expectedVersion !== void 0 ? expectedVersion : 3}`)) {
            throw new Error(`Expected OpenSSL version ${expectedVersion !== null && expectedVersion !== void 0 ? expectedVersion : 3}.x, got ${version}!`);
        }
        return command({ cmd: 'openssl', args, debug });
    },
});
export const initDb = async ({ certsDir, debug, }) => {
    try {
        await stat(path.join(certsDir, 'index.txt'));
    }
    catch {
        await writeFile(path.join(certsDir, 'index.txt'), '');
        await writeFile(path.join(certsDir, 'index.txt.attr'), 'unique_subject = no');
        const serial = await openssl({ debug }).command('rand', '-hex', '16');
        await writeFile(path.join(certsDir, 'serial'), serial);
    }
};
