import { randomUUID } from 'node:crypto';
import { mkdtempSync, writeFileSync } from 'node:fs';
import os from 'node:os';
import path from 'node:path';
export const opensslConfig = ({ dir, privateKeyFile, certificateFile, validDays, }) => {
    const config = [
        `[ ca ]`,
        `default_ca = CA_default`,
        `[ CA_default ]`,
        `dir               = ${dir}`,
        `new_certs_dir     = $dir`,
        `database          = $dir/index.txt`,
        `serial            = $dir/serial`,
        `private_key       = ${privateKeyFile}`,
        `certificate       = ${certificateFile}`,
        `default_md        = sha256`,
        `name_opt          = ca_default`,
        `cert_opt          = ca_default`,
        `default_days      = ${validDays !== null && validDays !== void 0 ? validDays : 375}`,
        `preserve          = no`,
        `policy            = policy_loose`,
        `[ policy_loose ]`,
        `countryName             = optional`,
        `stateOrProvinceName     = optional`,
        `localityName            = optional`,
        `organizationName        = optional`,
        `organizationalUnitName  = optional`,
        `commonName              = supplied`,
        `emailAddress            = optional`,
        `[ req ]`,
        `default_bits        = 2048`,
        `distinguished_name  = req_distinguished_name`,
        `string_mask         = utf8only`,
        `default_md          = sha256`,
        `x509_extensions     = v3_ca`,
        `[ req_distinguished_name ]`,
        `commonName                      = Common Name`,
        `[ v3_ca ]`,
        `subjectKeyIdentifier = hash`,
        `authorityKeyIdentifier = keyid:always,issuer`,
        `basicConstraints = critical, CA:true`,
        `keyUsage = critical, digitalSignature, cRLSign, keyCertSign`,
        `[ v3_intermediate_ca ]`,
        `subjectKeyIdentifier = hash`,
        `authorityKeyIdentifier = keyid:always,issuer`,
        `basicConstraints = critical, CA:true`,
        `keyUsage = critical, digitalSignature, cRLSign, keyCertSign`,
        `[ usr_cert ]`,
        `basicConstraints = CA:FALSE`,
        `nsComment = "OpenSSL Generated Client Certificate"`,
        `subjectKeyIdentifier = hash`,
        `authorityKeyIdentifier = keyid,issuer`,
        `keyUsage = critical, nonRepudiation, digitalSignature, keyEncipherment`,
        `extendedKeyUsage = clientAuth`,
    ].join(os.EOL);
    const tempDir = mkdtempSync(path.join(os.tmpdir(), 'nrf-asset-tracker-azure-certs-'));
    const configFile = path.join(tempDir, `openssl-${randomUUID()}.conf`);
    writeFileSync(configFile, config, 'utf-8');
    return configFile;
};
